@@ -1,6 +1,15 @@
 /*
  *	Core I2O structure managment
  *
+ *	(C) Copyright 1999   Red Hat Software
+ *	
+ *	Written by Alan Cox, Building Number Three Ltd
+ *
+ *	This program is free software; you can redistribute it and/or
+ *	modify it under the terms of the GNU General Public License
+ * 	as published by the Free Software Foundation; either version
+ *	2 of the License, or (at your option) any later version.
+ *
  *	A lot of the I2O message side code from this is taken from the
  *	Red Creek RCPCI45 adapter driver by Red Creek Communications
  */
@@ -330,7 +339,7 @@ static u32 i2o_wait_reply(struct i2o_controller *c, char *why)
  */
  
 
-int i2o_query_table(struct i2o_controller *c, int tid, void *buf, int buflen, 
+static int i2o_query_table(struct i2o_controller *c, int tid, void *buf, int buflen, 
 	int group, int field, u32 *key, int keylen)
 {
 	u32 m;
@@ -429,7 +438,7 @@ int i2o_query_table(struct i2o_controller *c, int tid, void *buf, int buflen,
 }
 
 
-int i2o_query_scalar(struct i2o_controller *c, int tid, void *buf, int buflen, 
+static int i2o_query_scalar(struct i2o_controller *c, int tid, void *buf, int buflen, 
 	int group, int field)
 {
 	u32 m;
@@ -1156,3 +1165,21 @@ int i2o_online_controller(struct i2o_controller *c)
 	
 	return 0;
 }
+
+EXPORT_SYMBOL(i2o_install_handler);
+EXPORT_SYMBOL(i2o_remove_handler);
+EXPORT_SYMBOL(i2o_install_device);
+EXPORT_SYMBOL(i2o_delete_device);
+EXPORT_SYMBOL(i2o_install_controller);
+EXPORT_SYMBOL(i2o_delete_controller);
+EXPORT_SYMBOL(i2o_unlock_controller);
+EXPORT_SYMBOL(i2o_find_controller);
+EXPORT_SYMBOL(i2o_claim_device);
+EXPORT_SYMBOL(i2o_release_device);
+EXPORT_SYMBOL(i2o_run_queue);
+EXPORT_SYMBOL(i2o_report_controller_unit);
+EXPORT_SYMBOL(i2o_activate_controller);
+EXPORT_SYMBOK(i2o_online_controller);
+
+MODULE_AUTHOR("Red Hat Software");
+MODULE_DESCRIPTION("I2O Core");
